@@ -4,6 +4,7 @@ import boto3
 from io import BytesIO
 import uuid
 import os
+from sharedkernel.multipart_upload import MultipartUploadSession
 
 class S3Uploader:
     def __init__(self, endpoint_url, bucket, access_key, secret_key):
@@ -82,5 +83,24 @@ class S3Uploader:
         file_obj = BytesIO(response.content)
         return self.upload_file_object(file_obj=file_obj, object_name=object_name, file_extension=file_extension, folder_name=folder_name)
 
+    def create_multipart_session(
+        self,
+        object_name=None,
+        file_extension=None,
+        folder_name=None,
+        public_read=True,
+    ):
+        object_key = self.__generate_object_name(
+            object_name, file_extension, folder_name
+        )
+
+        acl = "public-read" if public_read else "private"
+
+        return MultipartUploadSession(
+            s3_client=self.s3,
+            bucket=self.bucket,
+            object_key=object_key,
+            acl=acl,
+        )
 
 
